# Utility and View

Utility commands are used to do the following:

- Create SymbolicConstant and Boolean objects.
- Change the name of a key to a Repository object.
- Control the use of deprecated commands.
- Request input from the user.
- Display status information.
- Execute Python commands or functions.
- Register a callback that will be invoked when certain Abaqus Scripting Interface commands are about to be executed.
- Register a callback that will be invoked when certain Abaqus Scripting Interface objects are about to be deleted.
- Upgrade Abaqus kernel or GUI scripts from one release of Abaqus to a later release.

View commands are used to transform three-dimensional views stored in Session and Viewport objects to the screen. (See Session object and Viewport object.)

## Classes

### AbaqusBoolean

```{eval-rst}
.. autoclass:: abaqus.UtilityAndView.AbaqusBoolean.AbaqusBoolean
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BackwardCompatibility

```{eval-rst}
.. autoclass:: abaqus.UtilityAndView.BackwardCompatibility.BackwardCompatibility
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Callback

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.Callback
    :members:
    :special-members: __init__
    :show-inheritance:
```

### Customization

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.Customization
    :members:
    :special-members: __init__
    :show-inheritance:
```

### Delete

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.Delete
    :members:
    :special-members: __init__
    :show-inheritance:
```

### Method

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.Method
    :members:
    :special-members: __init__
    :show-inheritance:
```

### Repository

```{eval-rst}
.. autoclass:: abaqus.UtilityAndView.Repository.Repository
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Status

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.Status
    :members:
    :special-members: __init__
    :show-inheritance:
```

### SymbolicConstant

```{eval-rst}
.. autoclass:: abaqus.UtilityAndView.SymbolicConstant.SymbolicConstant
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### abaqusConstants

```{eval-rst}
.. autoclass:: abaqus.UtilityAndView.SymbolicConstant.abaqusConstants
    :members:
    :special-members: __init__
    :show-inheritance:
```

### Upgrade

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.Upgrade
    :members:
    :special-members: __init__
    :show-inheritance:
```

### User

```{eval-rst}
.. automodule:: abaqus.UtilityAndView.User
    :members:
```

### View

```{eval-rst}
.. autoclass:: abaqus.UtilityAndView.View.View
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
